import { makeAutoObservable } from "mobx";
import { UserRepository } from "./UserRepository";
import { User } from "./entities/User";
import { RouteObject } from "react-router";

export class UserService {
  user: User;
  isLoggedIn: boolean;
  roleRoutes: RouteObject[];
  constructor(private userRepository: UserRepository) {
    this.user = new User();
    this.isLoggedIn = false;
    this.roleRoutes = [];
    makeAutoObservable(this);
  }

  async signIn(user: Pick<User, "username" | "password">) {
    const { code, data, msg } = await this.userRepository.authLogin(user);
    this.user.signIn(data as User);
    return { success: code === 0, msg, data: data as User };
  }

  /**
   * 设置角色路由
   */
  setRoleRoutes(routeObjects: RouteObject[]) {
    this.roleRoutes = routeObjects;
  }

  /**
   * 获取用户信息
   */
  async userAuth() {
    const { code, data, msg } = await this.userRepository.userAuth();
    if (code === 0 && data?.tokenValid) {
      this.user.signIn(data.payload as User);
      return { success: true, data };
    } else {
      this.user.signOut();
      return { success: false, msg };
    }
  }

  /**
   * 获取标注人员信息
   */
  async getDmpAnnotators() {
    return await this.userRepository.getDmpAnnotators();
  }
}
