import { User } from "@@/domain/User/entities/User";
import { Request } from "./Request";

const PREFIX = "/api/dmp";
const PREFIX_CERT = "/cert";
const PREFIX_PACS = "/dicom-web";

type ResponseType = Promise<{
  code?: number | string;
  data?: unknown;
  msg?: string;
}>;

type ResponsePacsType = Promise<{
  ID: string;
  ParentPatient: string;
  ParentSeries: string;
  ParentStudy: string;
  Path: string;
  Status: string;
}>;

export type ExistInPacsDTO = {
  StudyInstanceUID: string;
  SeriesInstanceUID: string;
};

export const Apis = {
  /**
   * 用户登录
   */
  signIn: (p: Pick<User, "username" | "password">): ResponseType =>
    Request.post(PREFIX + "/auth/signIn", p),
  /**
   * 用户认证
   */
  userAuth: (): ResponseType => Request.get(PREFIX_CERT + "/auth/user"),
  /**
   * 上传dcm到pacs
   */
  upload2Pacs: (fd: FormData): ResponsePacsType =>
    Request.post(PREFIX_PACS + "/instances", fd, {
      headers: {
        "Content-Type": "multipart/form-data",
      },
    }),
  /**
   * pacs当中是否存在该序列，返回切片数量对比上传的File[].length
   */
  existInPacs: ({
    StudyInstanceUID,
    SeriesInstanceUID,
  }: ExistInPacsDTO): Promise<[]> =>
    Request.get(
      PREFIX_PACS +
        `/dicom-web/studies/${StudyInstanceUID}/series/${SeriesInstanceUID}/instances`
    ),
  /**
   * 获取标注人员信息
   */
  getDmpAnnotators: (): ResponseType =>
    Request.get(PREFIX + `/user/find/annotator`),
};
