import * as dicomParser from "dicom-parser";

export interface Series {
  SeriesInstanceUID: string;
  sliceThickness: string;
  seriesDescription: string;
  /**
   * 成像设备
   */
  modality: string;
  /**
   * 设备商
   */
  manufacturer: string;
  subs: File[];
}

export interface Study {
  StudyInstanceUID: string;
  studyDescription: string;
  patientID: string;
  patientAge: string;
  patientName: string;
  patientSex: string;
  acquisitionDate: string;
  subs: Series[];
}

/**
 * 结构化解析dcmFiles
 * @param {File[]} dcmFiles 上传浏览器读取的File类
 */
export const parseDcmFiles = async (dcmFiles: File[]): Promise<Study[]> => {
  const studys: Study[] = [];

  for (const file of dcmFiles) {
    const arrayBuffer = await file.arrayBuffer();
    const byteArray = new Uint8Array(arrayBuffer);
    const dataSet = dicomParser.parseDicom(byteArray);

    const patientID = dataSet.string("x00100020") ?? "无";
    const StudyInstanceUID = dataSet.string("x0020000d");
    const studyDescription = dataSet.string("x00081030") ?? "无";
    const SeriesInstanceUID = dataSet.string("x0020000e");
    const patientName = dataSet.string("x00100010") ?? "无";
    const patientSex = dataSet.string("x00100040") ?? "无";
    const patientAge = dataSet.string("x00101010") ?? "无";
    const sliceThickness = dataSet.string("x00180050");
    const acquisitionDate = dataSet.string("x00080022") ?? "无";
    const seriesDescription = dataSet.string("x0008103e") ?? "无";
    const modality = dataSet.string("x00080060") ?? "无";
    const manufacturer = dataSet.string("x00081090") ?? "无";

    if (StudyInstanceUID && SeriesInstanceUID && sliceThickness) {
      // 病例级别
      let study = studys.find((s) => s.StudyInstanceUID === StudyInstanceUID);
      if (!study) {
        study = {
          StudyInstanceUID,
          studyDescription,
          patientID,
          patientName,
          patientSex,
          patientAge,
          acquisitionDate,
          subs: [],
        };
        studys.push(study);
      }
      // 序列级别
      let series = study.subs.find(
        (s) => s.SeriesInstanceUID === SeriesInstanceUID
      );
      if (!series) {
        series = {
          SeriesInstanceUID,
          sliceThickness,
          seriesDescription,
          modality,
          manufacturer,
          subs: [],
        };
        study.subs.push(series);
      }
      series.subs.push(file);
    }
  }
  return studys;
};
