import { Button, Col, Row, Space, Spin } from "antd";
import { useDicomUploader } from "./DicomUploader";
import { Series, Study } from "./DicomUploader/util";
import { DicomTable } from "./DicomTable";
import { useDomain } from "@/hook/useDomain";
import { Typography } from "antd";
import { useState } from "react";

const { Text } = Typography;

interface DicomUploadProps {
  children?: JSX.Element;
}

export const DicomUpload = (props: DicomUploadProps) => {
  const { UploadInput, fileCalculator, studys, isLoading } = useDicomUploader();
  const { dicomDomainService } = useDomain();
  const { dcmFileNum, totalFileNum, dcmFileSize } = fileCalculator;
  const [selectRows, setSelectedRows] = useState<Study[]>([]);

  const onUploadFiles = async (study: Study, series: Series) => {
    const { SeriesInstanceUID, subs } = series;
    const { StudyInstanceUID } = study;
    const instances = await dicomDomainService.existInPacs({
      SeriesInstanceUID,
      StudyInstanceUID,
    });
    const dcmExistInPacs = instances.length === subs.length;
    if (dcmExistInPacs) {
      const target = `http://localhost:3000/viewer/${StudyInstanceUID}?SeriesInstanceUID=${SeriesInstanceUID}`;
      window.open(target, "_blank");
    } else {
      let fullfilled = 0;
      Promise.all(
        series.subs.map((file) =>
          dicomDomainService.upload2Pacs(file).then((res) => {
            if (["success", "AlreadyStored"].includes(res.Status)) {
              fullfilled++;
            }
          })
        )
      ).then((res) => {
        if (res.length === series.subs.length) {
          const target = `http://localhost:3000/viewer/${StudyInstanceUID}?SeriesInstanceUID=${SeriesInstanceUID}`;
          window.open(target, "_blank");
        }
      });
    }
  };

  const onClickAssign = () => {
    console.log(selectRows);
  };

  return (
    <div>
      <header>
        <Row style={{ padding: "10px 0" }}>
          <Col span={16}>
            <UploadInput />
            <Text type="secondary">
              文件统计, dicom文件: {dcmFileNum}, 总文件: {totalFileNum}, 大小:
              {dcmFileSize}
            </Text>
          </Col>
          <Col span={8} style={{ textAlign: "right" }}>
            <Space>
              <Button type="primary" size="small" onClick={onClickAssign}>
                分配
              </Button>
              <Button type="primary" size="small">
                添加标签
              </Button>
              <Button type="primary" size="small">
                备注
              </Button>
            </Space>
          </Col>
        </Row>
      </header>
      <DicomTable
        studys={studys}
        loading={isLoading}
        onSelectedRows={(rows) => setSelectedRows(rows)}
        onUploadFiles={onUploadFiles}
      />
    </div>
  );
};
